==> OpenPatricianDisplay-0.4.0-sources.jar: ch/sahits/game/graphic/javafx/display/PortSceneEventHandler.java <==
package ch.sahits.game.graphic.javafx.display;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.graphic.display.dialog.util.EDialogType;
import ch.sahits.game.graphic.display.gameplay.internal.EScene;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.graphic.display.notice.ENoticeItem;
import com.google.common.base.Preconditions;
import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.stereotype.Component;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 12, 2013
 */
@Component
public class PortSceneEventHandler implements ISceneEventHandler {
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);

    private IDialogContoller dialogContoller; // this instance exists not at startup
    @Override
    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    @Override
    public void setDialogContoller(IDialogContoller dialogContoller) {
        this.dialogContoller = dialogContoller;
    }

    @Override
    public void handleEvent(Object eventNotice) {
        Preconditions.checkNotNull(dialogContoller, "Dialog controller must be initialized first");
                   if (eventNotice == EViewChangeEvent.CLOSE_DIALOG) {
                       dialogContoller.closeDialog();
                   }
                   if (eventNotice instanceof ViewChangeCityPlayerProxyJFX) {
                       ViewChangeCityPlayerProxyJFX cityProxy = (ViewChangeCityPlayerProxyJFX) eventNotice;
                       // trade city ship
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_TRADE) {
                           // Dialog City ship
                           dialogContoller.setNewDialog(EDialogType.CITY_TO_SHIP);
                       }
                       // trading office
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_TRADING_OFFICE) {
                           // Dialog City ship
                           dialogContoller.setNewDialog(EDialogType.TO_BALANCE);
                       }
                       // Scene change market place
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_MARKET) {
                           currentScene.set(EScene.MARKET);
                           dialogContoller.changeScene();
                       }
                       // Scene change shipyard
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_SHIPYARD) {
                           currentScene.set(EScene.SHIPYARD);
                           dialogContoller.changeScene();
                       }
                       // Scene change tavern
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_TAVERN) {
                           currentScene.set(EScene.TAVERN);
                           dialogContoller.changeScene();
                       }
                       // Scene change loaner office
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_LOANER) {
                           currentScene.set(EScene.LOANER);
                           dialogContoller.changeScene();
                       }

                   }
                   if (eventNotice instanceof ENoticeItem) {
                       EDialogType dialogType;
                       switch ((ENoticeItem)eventNotice) {
                           case PORT_CITY_TO_SHIP:
                               dialogType = EDialogType.CITY_TO_SHIP;
                               break;
                           case PORT_CITY_TO_STORAGE:
                               dialogType = EDialogType.CITY_TO_STORAGE;
                               break;
                           case PORT_STORAGE_TO_SHIP:
                               dialogType = EDialogType.STORAGE_TO_SHIP;
                               break;
                           case TO_BALANCE:
                               dialogType = EDialogType.TO_BALANCE;
                               break;
                           case TO_PERSONAL:
                               dialogType = EDialogType.TO_PERSONAL;
                               break;
                           case TO_CONSUMPTION_PRODUCTION:
                               dialogType = EDialogType.TO_CONSUMPTION_PRODUCTION;
                               break;
                           case TO_OFFICE_TRADING:
                               dialogType = EDialogType.TO_OFFICE_TRADING;
                               break;
                           case TO_WAREHOUSES:
                               dialogType = EDialogType.TO_WAREHOUSES;
                               break;
                           case TO_WEAPONS:
                               dialogType = EDialogType.TO_WEAPONS;
                               break;
                           default:
                               throw new RuntimeException("Not yet implemented eventNotice: "+eventNotice);
                       }
                       dialogContoller.replaceDialog(dialogType);
                   }
    }
}

==> OpenPatricianDisplay-0.8.0-sources.jar: ch/sahits/game/graphic/javafx/display/PortSceneEventHandler.java <==
package ch.sahits.game.graphic.javafx.display;

import ch.sahits.game.event.EViewChangeEvent;
import ch.sahits.game.graphic.display.gameplay.internal.EScene;
import ch.sahits.game.graphic.display.model.ViewChangeCityPlayerProxyJFX;
import ch.sahits.game.javafx.event.WrappedDialogType;
import ch.sahits.game.javafx.model.EDialogType;
import ch.sahits.game.openpatrician.annotation.ClassCategory;
import ch.sahits.game.openpatrician.annotation.DependentInitialisation;
import ch.sahits.game.openpatrician.annotation.EClassCategory;
import ch.sahits.game.openpatrician.annotation.ObjectPropertyType;
import ch.sahits.game.openpatrician.util.StartNewGameBean;
import com.google.common.base.Preconditions;
import javafx.beans.property.ObjectProperty;
import javafx.beans.property.SimpleObjectProperty;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;

/**
 * @author Andi Hotz, (c) Sahits GmbH, 2013
 *         Created on Dec 12, 2013
 */
@Component
@Lazy
@DependentInitialisation(StartNewGameBean.class)
@ClassCategory(EClassCategory.HANDLER)
public class PortSceneEventHandler implements ISceneEventHandler {
    @ObjectPropertyType(EScene.class)
    private ObjectProperty<EScene> currentScene = new SimpleObjectProperty<>(this, "currentScene", EScene.PORT);

    private IDialogContoller dialogContoller; // this instance exists not at startup
    @Override
    public ObjectProperty<EScene> currentSceneProperty() {
        return currentScene;
    }

    @Override
    public void setDialogContoller(IDialogContoller dialogContoller) {
        this.dialogContoller = dialogContoller;
    }

    @Override
    public void handleEvent(Object eventNotice) {
        Preconditions.checkNotNull(dialogContoller, "Dialog controller must be initialized first");
                   if (eventNotice instanceof ViewChangeCityPlayerProxyJFX) {
                       ViewChangeCityPlayerProxyJFX cityProxy = (ViewChangeCityPlayerProxyJFX) eventNotice;
                       // trade city ship
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_TRADE) {
                           // Dialog City ship
                           dialogContoller.setNewDialog(EDialogType.PORT_CITY_TO_SHIP);
                       }
                       // trading office
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.NOTICE_TRADING_OFFICE) {
                           // Dialog City ship
                           dialogContoller.setNewDialog(EDialogType.TO_BALANCE);
                       }
                       // Scene change market place
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_MARKET) {
                           currentScene.set(EScene.MARKET);
                           dialogContoller.changeScene();
                       }
                       // Scene change shipyard
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_SHIPYARD) {
                           currentScene.set(EScene.SHIPYARD);
                           dialogContoller.changeScene();
                       }
                       // Scene change tavern
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_TAVERN) {
                           currentScene.set(EScene.TAVERN);
                           dialogContoller.changeScene();
                       }
                       // Scene change loaner office
                       if (cityProxy.getViewChangeEvent() == EViewChangeEvent.MAIN_VIEW_LOANER) {
                           currentScene.set(EScene.LOANER);
                           dialogContoller.changeScene();
                       }

                   }
                   if (eventNotice instanceof EDialogType) {
                       dialogContoller.replaceDialog((EDialogType) eventNotice);
                   }
        if (eventNotice instanceof WrappedDialogType) {
            final WrappedDialogType notice = (WrappedDialogType) eventNotice;
            dialogContoller.replaceDialog(notice.getDialogType(), notice.getParams());
        }
    }
}
